@@ -145,7 +145,7 @@ def construct_alert(frm, channel, msg, elapsed=None):
     alert_title = frm + "@" + channel + ":"
     message = msg
     if elapsed:
-        message += " (" + round(seconds_listen_channel - elapsed) + "s left)"
+        message += " (" + str(round(seconds_listen_channel - elapsed)) + "s left)"
     return trim_leading_dashes(alert_title), trim_leading_dashes(message)
 
 
